scouting: Ask the user to reload after submitting match data
The current "Home" screen doesn't tell folks what to do. It's not
obvious that they have to reload the page at this point. This patch
changes the screen to ask the user to reload the page.
Signed-off-by: Philipp Schrader <philipp.schrader@gmail.com>
Change-Id: I88b7137eaace31c9cff36685992880cfb9d9eeda
diff --git a/scouting/www/entry/entry.component.ts b/scouting/www/entry/entry.component.ts
index 412306a..d06e117 100644
--- a/scouting/www/entry/entry.component.ts
+++ b/scouting/www/entry/entry.component.ts
@@ -10,7 +10,7 @@
import SubmitDataScoutingResponse = submit_data_scouting_response.scouting.webserver.requests.SubmitDataScoutingResponse;
import ErrorResponse = error_response.scouting.webserver.requests.ErrorResponse;
-type Section = 'Team Selection'|'Auto'|'TeleOp'|'Climb'|'Other'|'Review and Submit'|'Home'
+type Section = 'Team Selection'|'Auto'|'TeleOp'|'Climb'|'Other'|'Review and Submit'|'Success'
type Level = 'NoAttempt'|'Failed'|'FailedWithPlentyOfTime'|'Low'|'Medium'|'High'|'Transversal'
@Component({
@@ -117,8 +117,8 @@
'/requests/submit/data_scouting', {method: 'POST', body: buffer});
if (res.ok) {
- // We successfully submitted the data. Go back to Home.
- this.section = 'Home';
+ // We successfully submitted the data. Report success.
+ this.section = 'Success';
} else {
const resBuffer = await res.arrayBuffer();
const fbBuffer = new ByteBuffer(new Uint8Array(resBuffer));